Page 46 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 46

Home

    quoted as having said, "God save us from being saved by
    Lafayette."

    In the second great uprising of the Revolution, the
    march on Versailles, October 5 & 6, 1789, the same

    pattern was used as before. First create a crisis, then on
    the pretense of solving the crisis, lead the people to
    action with a hard core of hired revolutionaries. In this

    case, the manufactured crisis was the hunger caused by
    agents of the Orleaniste Conspiracy buying up the
    available grain, and withholding it from the people. The
    people of Paris were then told that the King and Queen
    were responsible for the shortage, and that they must
    march on the King's residence to obtain bread.

    As before, besides those who were actually hungry,
    many of the crowd had been bribed or forced to
    participate against their will. The women had been
    placed in the forefront to prevent the soldiers from using
    arms to disperse the crowd as they advanced. Among the
    women in the lead were several men dressed in women's

    clothing to disguise their identity.

    Two events prevented the overthrow of the Monarchy
    on this occasion. One was the bravery of the King in
    facing the crowd and his magnanimity in offering to give
    the bread in Versailles to feed the hungry. The other

    The one good thing that came out of the march on
    Versailles was the opening of the eyes of Lafayette to the

    41

    The French Revolution

    Because of Lafayette's wavering, the Queen was once

    event was the arrival of Lafayette to ‘put down the

    insurrection.